@@ -85,6 +85,7 @@ class GrammaticalEvolutionRepresentation(Representation[Genotype]):
         depth: int,
         ty: type,
         specific_type: type = None,
+        depth_aware_mut: bool = False,
     ) -> Genotype:
         return mutate(r, g, ind, depth)
 
@@ -96,6 +97,7 @@ class GrammaticalEvolutionRepresentation(Representation[Genotype]):
         i2: Genotype,
         depth: int,
         specific_type: type = None,
+        depth_aware_co: bool = False,
     ) -> tuple[Genotype, Genotype]:
         return crossover(r, g, i1, i2, depth)
 
