@@ -14,6 +14,7 @@ from typing import Tuple
 from typing import Type
 from typing import TYPE_CHECKING
 
+from geneticengine.algorithms.gp.individual import Individual
 from geneticengine.core.decorators import get_gengy
 
 if TYPE_CHECKING:
@@ -106,13 +107,13 @@ def is_abstract(t: type) -> bool:
     return t.mro()[1] in [ABC, Protocol] or get_gengy(t).get("abstract", False)
 
 
-def is_terminal(t: type, l: set[type]) -> bool:
+def is_terminal(t: type, non_terminals: set[type]) -> bool:
     """Returns whether a node is a terminal or not, based on the list of non terminals in the grammar"""
     if is_annotated(t):
-        return all([is_terminal(inner, l) for inner in get_generic_parameters(t)])
-    if not has_arguments(t):
-        return True
-    return t not in l
+        return all(
+            [is_terminal(inner, non_terminals) for inner in get_generic_parameters(t)],
+        )
+    return t not in non_terminals
 
 
 def all_init_arguments_typed(t: type) -> bool:
@@ -172,3 +173,10 @@ def build_finalizers(
         final_callback()
 
     return finalizers
+
+
+def average_fitness(individual: Individual) -> float:
+    """Returns the average fitness list value of the given individual"""
+    assert isinstance(individual.fitness, list)
+    average_fitness = sum(individual.fitness) / len(individual.fitness)
+    return average_fitness
